# ╔════════════════════════════════════════════════════════════════╗
# ║ "Optimally temperature compensated FBG-based sensor dedicated  ║
# ║       to non-intrusive pipe internal pressure monitoring"      ║
# ║ authors: Laurent Maurin, Nicolas Roussel and Guillaume Laffont ║
# ║          (Recent Advances in Optical Fiber Sensors)            ║
# ║                                                                ║
# ║ https://www.frontiersin.org/articles/10.3389/fsens.2022.835140 ║
# ║ https://hal-cea.archives-ouvertes.fr/cea-03541365              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ gnuplot scripts for figure 10 (left & right)                   ║
# ║ see http://www.gnuplot.info/ for more information              ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ this gnuplot script can be loaded with the gnuplot command:    ║
# ║   gnuplot> load "plot_eps.gnu"                                 ║
# ║ _ open data are located in the "data" sub-directory            ║
# ║ _ encapsulated postscript figures generated by this script are ║
# ║   located in the "graphs" sub-directory                        ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ script validated on Linux and Microsoft Windows workstations   ║
# ║ with gnuplot 5.4.2                                             ║
# ╠════════════════════════════════════════════════════════════════╣
# ║ before running, first relocate to the directory of this script ║
# ╚════════════════════════════════════════════════════════════════╝

set terminal eps enhanced color
set encoding utf8

set size 1,1
set xtics autofreq
set format x "% g"
set grid

# ************************************************
# figure 10 left
# ************************************************

data_P="data/data_figure_10_P.txt"

set lmargin 7.8
set rmargin 9.1

set output "graphs/figure_10_left.eps"

set multiplot

# --------------------

set key left top

set size 1,1
set origin 0.0,0.0

set bmargin 3
set tmargin 0.5

set format x "% g"

set xrange [0:600]
set xlabel "time [s]"
set xtics autofreq
set mxtics 10

set yrange [0:3.2]
set ylabel "{ΔP}_{FBG} [bar]"
set ytics autofreq
set ytics nomirror
set mytics 5

set y2range [0:0.25]
set y2label "{ΔT}_{TC} [°C]" rotate by -90
set y2tics
set my2tics 5

Young=200.0E9         # Young's modulus [GPa]
Poisson=0.3           # Poisson's ratio
r0int=0.1524/2.0      # initial inner radius [m]
r0ext=r0int+0.003     # initial outer radius [m]
Keps=0.78             # FBG mechanical strain sensitivity
KT=(12.0+6.45)*1E-6   # FBG temperature sensitivity once attached to the pipe [K⁻¹]
lambda0=1550.0        # reference FBG wavelength  [nm]
T0=19.9               # reference thermocouple temperature [°C]

plot data_P every ::1 using ($1):(1e-5*($5)/lambda0*Young*(r0ext**2-r0int**2)/(Keps*(1.0+Poisson)*r0int**2)) axes x1y1 with lines lw 0.5 title "{ΔP}_{FBG}", data_P every ::1 using ($1):((($2)+($3)+($4))/3.0-T0) axes x1y2 with lines lw 0.5 title "{ΔT}_{TC}"

unset multiplot
set output

# ************************************************
# figure 10 right
# ************************************************

data_flow="data/data_figure_10_flow.txt"

set lmargin 7.8
set rmargin 1.7

set output "graphs/figure_10_right.eps"

set multiplot

# --------------------

set key left top

set size 1,1
set origin 0.0,0.0

set bmargin 3
set tmargin 0.5

set format x "% g"

set xrange [75:*]
set xlabel "Q [{m}^{3}/h]"
set mxtics 5

set yrange [*:*]
set ylabel "{ΔP}_{FBG} [bar]"
set ytics autofreq
set ytics mirror
set mytics 5

unset y2label
unset y2tics

plot data_flow every ::1 using (3600.0*(0.02661*($1)-0.02778)):(1e-5*($2)/lambda0*Young*(r0ext**2-r0int**2)/(Keps*(1.0+Poisson)*r0int**2)) axes x1y1 with linespoints lw 0.5 title "{ΔP}_{FBG}"

unset multiplot
set output

# ************************************************

set terminal pop
